@@ -1,20 +1,6 @@
-#     Copyright 2023, Kay Hayen, mailto:kay.hayen@gmail.com
-#
-#     Part of "Nuitka", an optimizing Python compiler that is compatible and
-#     integrates with CPython, but also works on its own.
-#
-#     Licensed under the Apache License, Version 2.0 (the "License");
-#     you may not use this file except in compliance with the License.
-#     You may obtain a copy of the License at
-#
-#        http://www.apache.org/licenses/LICENSE-2.0
-#
-#     Unless required by applicable law or agreed to in writing, software
-#     distributed under the License is distributed on an "AS IS" BASIS,
-#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#     See the License for the specific language governing permissions and
-#     limitations under the License.
-#
+#     Copyright 2024, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+
+
 """ Eval/exec/execfile/compile built-in related codes. """
 
 from nuitka import Options
@@ -40,7 +26,8 @@ def _getStoreLocalsCode(locals_name, variable_traces, is_dict, emit, context):
 
             if is_dict:
                 emit(
-                    "%s = DICT_GET_ITEM0(%s, %s);" % (value_name, locals_name, key_name)
+                    "%s = DICT_GET_ITEM0(tstate, %s, %s);"
+                    % (value_name, locals_name, key_name)
                 )
             else:
                 emit(
@@ -50,13 +37,13 @@ def _getStoreLocalsCode(locals_name, variable_traces, is_dict, emit, context):
 
                 getErrorExitBoolCode(
                     condition="""\
-%s == NULL && !EXCEPTION_MATCH_BOOL_SINGLE(GET_ERROR_OCCURRED(), PyExc_KeyError)"""
+%s == NULL && !EXCEPTION_MATCH_BOOL_SINGLE(tstate, GET_ERROR_OCCURRED(tstate), PyExc_KeyError)"""
                     % value_name,
                     emit=emit,
                     context=context,
                 )
 
-                emit("CLEAR_ERROR_OCCURRED();")
+                emit("CLEAR_ERROR_OCCURRED(tstate);")
 
                 context.addCleanupTempName(value_name)
 
@@ -141,7 +128,6 @@ def generateBuiltinCompileCode(to_name, expression, emit, context):
     with withObjectCodeTemporaryAssignment(
         to_name, "compile_result", expression, emit, context
     ) as value_name:
-
         _getBuiltinCompileCode(
             to_name=value_name,
             source_name=source_name,
@@ -178,7 +164,10 @@ def _getBuiltinCompileCode(
             optimize_name,
         )
 
-    emit("%s = COMPILE_CODE(%s);" % (to_name, ", ".join(str(arg) for arg in args)))
+    emit(
+        "%s = COMPILE_CODE(tstate, %s);"
+        % (to_name, ", ".join(str(arg) for arg in args))
+    )
 
     getErrorExitCode(
         check_name=to_name,
@@ -204,6 +193,7 @@ def getBuiltinEvalCode(
     globals_name,
     locals_name,
     mode_name,
+    closure_name,
     emit,
     context,
 ):
@@ -222,13 +212,13 @@ def getBuiltinEvalCode(
     )
 
     emit(
-        "%s = EVAL_CODE(%s, %s, %s);"
-        % (to_name, compiled_name, globals_name, locals_name)
+        "%s = EVAL_CODE(tstate, %s, %s, %s, %s);"
+        % (to_name, compiled_name, globals_name, locals_name, closure_name or "NULL")
     )
 
     getErrorExitCode(
         check_name=to_name,
-        release_names=(compiled_name, globals_name, locals_name),
+        release_names=(compiled_name, globals_name, locals_name, closure_name),
         emit=emit,
         context=context,
     )
@@ -264,9 +254,11 @@ def generateExecCode(statement, emit, context):
     # Default filename with origin in improved mode.
     filename_name.getCType().emitAssignmentCodeFromConstant(
         to_name=filename_name,
-        constant="<string>"
-        if Options.is_full_compat
-        else "<string at %s>" % source_ref.getAsString(),
+        constant=(
+            "<string>"
+            if Options.is_full_compat
+            else "<string at %s>" % source_ref.getAsString()
+        ),
         may_escape=False,
         emit=emit,
         context=context,
@@ -283,11 +275,10 @@ def generateExecCode(statement, emit, context):
         if Options.is_full_compat
         else statement.getSourceReference()
     ):
-
         res_name = context.getBoolResName()
 
         emit(
-            "%s = EXEC_FILE_ARG_HANDLING(&%s, &%s);"
+            "%s = EXEC_FILE_ARG_HANDLING(tstate, &%s, &%s);"
             % (res_name, source_name, filename_name)
         )
 
@@ -312,7 +303,7 @@ def generateExecCode(statement, emit, context):
         to_name = context.allocateTempName("exec_result")
 
         emit(
-            "%s = EVAL_CODE(%s, %s, %s);"
+            "%s = EVAL_CODE(tstate, %s, %s, %s, NULL);"
             % (to_name, compiled_name, globals_name, locals_name)
         )
 
@@ -368,6 +359,22 @@ def _generateEvalCode(to_name, node, emit, context):
     else:
         filename = "<execfile>"
 
+    if (
+        python_version >= 0x31B
+        and node.isExpressionBuiltinExec()
+        and node.subnode_closure is not None
+    ):
+        closure_name = context.allocateTempName("eval_closure")
+
+        generateExpressionCode(
+            to_name=closure_name,
+            expression=node.subnode_closure,
+            emit=emit,
+            context=context,
+        )
+    else:
+        closure_name = None
+
     getBuiltinEvalCode(
         to_name=to_name,
         source_name=source_name,
@@ -377,6 +384,7 @@ def _generateEvalCode(to_name, node, emit, context):
         mode_name=context.getConstantCode(
             constant="eval" if node.isExpressionBuiltinEval() else "exec"
         ),
+        closure_name=closure_name,
         emit=emit,
         context=context,
     )
@@ -418,3 +426,19 @@ def generateLocalsDictSyncCode(statement, emit, context):
             emit=emit,
             context=context,
         )
+
+
+#     Part of "Nuitka", an optimizing Python compiler that is compatible and
+#     integrates with CPython, but also works on its own.
+#
+#     Licensed under the Apache License, Version 2.0 (the "License");
+#     you may not use this file except in compliance with the License.
+#     You may obtain a copy of the License at
+#
+#        http://www.apache.org/licenses/LICENSE-2.0
+#
+#     Unless required by applicable law or agreed to in writing, software
+#     distributed under the License is distributed on an "AS IS" BASIS,
+#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#     See the License for the specific language governing permissions and
+#     limitations under the License.
