@@ -1,20 +1,6 @@
-#     Copyright 2023, Kay Hayen, mailto:kay.hayen@gmail.com
-#
-#     Part of "Nuitka", an optimizing Python compiler that is compatible and
-#     integrates with CPython, but also works on its own.
-#
-#     Licensed under the Apache License, Version 2.0 (the "License");
-#     you may not use this file except in compliance with the License.
-#     You may obtain a copy of the License at
-#
-#        http://www.apache.org/licenses/LICENSE-2.0
-#
-#     Unless required by applicable law or agreed to in writing, software
-#     distributed under the License is distributed on an "AS IS" BASIS,
-#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#     See the License for the specific language governing permissions and
-#     limitations under the License.
-#
+#     Copyright 2024, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+
+
 """ Frame nodes.
 
 The frame attaches name and other frame properties to a scope, where it is
@@ -38,16 +24,12 @@ from .StatementNodes import StatementsSequence
 def checkFrameStatements(value):
     """Check that frames statements list value proper.
 
-    Must not be None, must not contain None, and of course only statements
-    sequences, or statements, may be empty.
+    Must not be None, must not contain None, may be empty though.
     """
 
     assert value is not None
     assert None not in value
 
-    for statement in value:
-        assert statement.isStatement() or statement.isStatementsFrame(), statement
-
     return tuple(value)
 
 
@@ -390,3 +372,19 @@ class StatementsFrameAsyncgen(StatementsFrameGeneratorBase):
     @staticmethod
     def getStructureMember():
         return "asyncgen"
+
+
+#     Part of "Nuitka", an optimizing Python compiler that is compatible and
+#     integrates with CPython, but also works on its own.
+#
+#     Licensed under the Apache License, Version 2.0 (the "License");
+#     you may not use this file except in compliance with the License.
+#     You may obtain a copy of the License at
+#
+#        http://www.apache.org/licenses/LICENSE-2.0
+#
+#     Unless required by applicable law or agreed to in writing, software
+#     distributed under the License is distributed on an "AS IS" BASIS,
+#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#     See the License for the specific language governing permissions and
+#     limitations under the License.
