@@ -1,20 +1,6 @@
-#     Copyright 2023, Kay Hayen, mailto:kay.hayen@gmail.com
-#
-#     Python tests originally created or extracted from other peoples work. The
-#     parts were too small to be protected.
-#
-#     Licensed under the Apache License, Version 2.0 (the "License");
-#     you may not use this file except in compliance with the License.
-#     You may obtain a copy of the License at
-#
-#        http://www.apache.org/licenses/LICENSE-2.0
-#
-#     Unless required by applicable law or agreed to in writing, software
-#     distributed under the License is distributed on an "AS IS" BASIS,
-#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#     See the License for the specific language governing permissions and
-#     limitations under the License.
-#
+#     Copyright 2024, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+
+
 """ Reference counting tests.
 
 These contain functions that do specific things, where we have a suspect
@@ -188,7 +174,7 @@ def simpleFunction16():
 
 
 def simpleFunction17():
-    class EmptyObjectClass:
+    class EmptyObjectClass(object):
         pass
 
     return EmptyObjectClass()
@@ -1042,6 +1028,9 @@ def simpleFunction111():
 
 
 def simpleFunction112():
+    if sys.version_info >= (3, 12):
+        return
+
     TESTFN = "tmp.txt"
     import codecs
 
@@ -1372,6 +1361,22 @@ result = executeReferenceChecked(
     names=globals(),
     tests_skipped=tests_skipped,
     tests_stderr=tests_stderr,
+    explain=False,
 )
 
 sys.exit(0 if result else 1)
+
+#     Python tests originally created or extracted from other peoples work. The
+#     parts were too small to be protected.
+#
+#     Licensed under the Apache License, Version 2.0 (the "License");
+#     you may not use this file except in compliance with the License.
+#     You may obtain a copy of the License at
+#
+#        http://www.apache.org/licenses/LICENSE-2.0
+#
+#     Unless required by applicable law or agreed to in writing, software
+#     distributed under the License is distributed on an "AS IS" BASIS,
+#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#     See the License for the specific language governing permissions and
+#     limitations under the License.
